searchData={"items":[{"type":"module","title":"Buffy","doc":"Buffy is broken down into different modules depending on how you want to\nhandle your function calling.","ref":"Buffy.html"},{"type":"module","title":"Throttle - Buffy","doc":"The `Buffy.Throttle` module will wait for a specified amount of time before\ninvoking the function. If the function is called again before the time has\nelapsed, it's a no-op. Once the timer has expired, the function will be called,\nand any subsequent calls will start a new timer.\n\n```text\ncall     call   call               call           call\n | call   | call | call             | call         |\n |  |     |  |   |  |               |  |           |\n┌─────────┐  ┌─────────┐            ┌─────────┐    ┌─────────┐\n│ Timer 1 │  │ Timer 2 │            │ Timer 3 │    │ Timer 4 │\n└─────────|  └─────────┘            └─────────┘    └─────────┘\n          |            |                      |              |\n          |            |                      |    Forth function invocation\n          |            |            Third function invocation\n          | Second function invocation\nFirst function invocation\n```","ref":"Buffy.html#module-throttle"},{"type":"module","title":"Buffy.Application","doc":"The Buffy supervisor responsible for starting the default\n`Registry` and `DynamicSupervisor`.","ref":"Buffy.Application.html"},{"type":"behaviour","title":"Buffy.Throttle","doc":"The `Buffy.Throttle` module will wait for a specified amount of time before\ninvoking the function. If the function is called again before the time has\nelapsed, it's a no-op. Once the timer has expired, the function will be called,\nand any subsequent calls will start a new timer.\n\n```text\ncall     call   call               call           call\n | call   | call | call             | call         |\n |  |     |  |   |  |               |  |           |\n┌─────────┐  ┌─────────┐            ┌─────────┐    ┌─────────┐\n│ Timer 1 │  │ Timer 2 │            │ Timer 3 │    │ Timer 4 │\n└─────────|  └─────────┘            └─────────┘    └─────────┘\n          |            |                      |              |\n          |            |                      |    Forth function invocation\n          |            |            Third function invocation\n          | Second function invocation\nFirst function invocation\n```","ref":"Buffy.Throttle.html"},{"type":"behaviour","title":"Example Usage - Buffy.Throttle","doc":"You'll first need to create a module that will be used to throttle.\n\n    defmodule MyTask do\n      use Buffy.Throttle,\n        throttle: :timer.minutes(2)\n\n      def handle_throttle(args) do\n        # Do something with args\n      end\n    end\n\nNext, you can use the `throttle/1` function with the registered module.\n\n    iex> MyTask.throttle(args)\n    :ok","ref":"Buffy.Throttle.html#module-example-usage"},{"type":"behaviour","title":"Options - Buffy.Throttle","doc":"- `:jitter` (`integer`) - Optional. The amount of jitter or randomosity to add to the throttle function handle. This value is in milliseconds. Defaults to `0`.\n\n  - `:registry_module` (`atom`) - Optional. A module that implements the `Registry` behaviour. If you are running in a distributed instance, you can set this value to `Horde.Registry`. Defaults to `Registry`.\n\n  - `:registry_name` (`atom`) - Optional. The name of the registry to use. Defaults to the built in Buffy registry, but if you are running in a distributed instance you can set this value to a named `Horde.Registry` process. Defaults to `Buffy.Registry`.\n\n  - `:restart` (`:permanent` | `:temporary` | `:transient`) - Optional. The restart strategy to use for the GenServer. Defaults to `:temporary`.\n\n  - `:supervisor_module` (`atom`) - Optional. A module that implements the `DynamicSupervisor` behaviour. If you are running in a distributed instance, you can set this value to `Horde.DynamicSupervisor`. Defaults to `DynamicSupervisor`.\n\n  - `:supervisor_name` (`atom`) - Optional. The name of the dynamic supervisor to use. Defaults to the built in Buffy dynamic supervisor, but if you are running in a distributed instance you can set this value to a named `Horde.DynamicSupervisor` process. Defaults to `Buffy.DynamicSupervisor`.\n\n  - :throttle (`non_neg_integer`) - Required. The minimum amount of time to wait before invoking the function. This value is in milliseconds. The actual run time could be longer than this value based on the `:jitter` option.","ref":"Buffy.Throttle.html#module-options"},{"type":"behaviour","title":"Using with Horde - Buffy.Throttle","doc":"If you are running Elixir in a cluster, you can utilize `Horde` to only run one of your throttled functions at a time. To do this, you'll need to set the `:registry_module` and `:supervisor_module` options to `Horde.Registry` and `Horde.DynamicSupervisor` respectively. You'll also need to set the `:registry_name` and `:supervisor_name` options to the name of the Horde registry and dynamic supervisor you want to use.\n\n      defmodule MyThrottler do\n        use Buffy.Throttle,\n          registry_module: Horde.Registry,\n          registry_name: MyApp.HordeRegistry,\n          supervisor_module: Horde.DynamicSupervisor,\n          supervisor_name: MyApp.HordeDynamicSupervisor,\n          throttle: :timer.minutes(2)\n\n        def handle_throttle(args) do\n          # Do something with args\n        end\n      end","ref":"Buffy.Throttle.html#module-using-with-horde"},{"type":"behaviour","title":"Telemetry - Buffy.Throttle","doc":"These are the events that are called by the `Buffy.Throttle` module:\n\n- `[:buffy, :throttle, :throttle]` - Emitted when the `throttle/1` function is called.\n- `[:buffy, :throttle, :handle, :jitter]` - Emitted before the `handle_throttle/1` function is called with the amount of jitter added to the throttle.\n- `[:buffy, :throttle, :handle, :start]` - Emitted at the start of the `handle_throttle/1` function.\n- `[:buffy, :throttle, :handle, :stop]` - Emitted at the end of the `handle_throttle/1` function.\n- `[:buffy, :throttle, :handle, :exception]` - Emitted when an error is raised in the `handle_throttle/1` function.\n\nAll of these events will have the following metadata:\n\n- `:args` - The arguments passed to the `throttle/1` function.\n- `:key` - A hash of the passed arguments used to deduplicate the throttled function.\n- `:module` - The module using `Buffy.Throttle`.\n\nWith the additional metadata for `[:buffy, :throttle, :handle, :stop]`:\n\n- `:result` - The return value of the `handle_throttle/1` function.","ref":"Buffy.Throttle.html#module-telemetry"},{"type":"callback","title":"Buffy.Throttle.handle_throttle/1","doc":"The function called after the throttle has completed. This function will\nreceive the arguments passed to the `throttle/1` function.","ref":"Buffy.Throttle.html#c:handle_throttle/1"},{"type":"callback","title":"Buffy.Throttle.throttle/1","doc":"A function to call the throttle. This will start\nand wait the configured `throttle` time before calling the `c:handle_throttle/1`\nfunction.","ref":"Buffy.Throttle.html#c:throttle/1"},{"type":"type","title":"Buffy.Throttle.args/0","doc":"A list of arbitrary arguments that are used for the `c:handle_throttle/1`\nfunction.","ref":"Buffy.Throttle.html#t:args/0"},{"type":"type","title":"Buffy.Throttle.key/0","doc":"A unique key for debouncing. This is used for GenServer uniqueness and is\ngenerated from hashing all of the args.","ref":"Buffy.Throttle.html#t:key/0"},{"type":"type","title":"Buffy.Throttle.state/0","doc":"Internal state that `Buffy.Throttle` keeps.","ref":"Buffy.Throttle.html#t:state/0"},{"type":"behaviour","title":"Buffy.ThrottleAndTimed","doc":"This is a variation on the `Buffy.Throttle` behavior.\n\nIt keeps the following functionality:\n  - wait for a specified amount of time before\ninvoking the work function. If the function is called again before the time has\nelapsed, it's a no-op.\n\nKey difference between `Buffy.Throttle` and `Buffy.ThrottleAndTimed`:\n  - it will not be terminated once the timer is done, but kept alive\n    - internally, the existing timer behavior is done via state rather than handling `{:error, {:already_started, pid}}` output of `GenServer.start_link`.\n      - See note on Horde about state.\n  - it has an optional `:loop_interval` field value (set by config) to trigger work repeatedly based on a empty inbox timeout interval,\n    that is based on [GenServer's timeout feature](https://hexdocs.pm/elixir/1.15/GenServer.html#module-timeouts).\n  - allows for manipulating state for each `throttle` via `defoveridable` functions (see [use case below](#module-example-usage-1))\n\nMain reason for these changes is sometimes there's a need to fall back to a time-interval triggered work, when there aren't any triggers to\nstart the work. Requirement of this means the process should exist and not get terminated immediately after a successfully throttled work execution.\n\n#","ref":"Buffy.ThrottleAndTimed.html"},{"type":"behaviour","title":"In other words, we keep the throttle mechanism: - Buffy.ThrottleAndTimed","doc":"Once the timer has expired, the function will be called,\nand any subsequent calls will start a new timer.\n\n```text\ncall     call   call               call           call\n | call   | call | call             | call         |\n |  |     |  |   |  |               |  |           |\n┌─────────┐  ┌─────────┐            ┌─────────┐    ┌─────────┐\n│ Timer 1 │  │ Timer 2 │            │ Timer 3 │    │ Timer 4 │\n└─────────|  └─────────┘            └─────────┘    └─────────┘\n          |            |                      |              |\n          |            |                      |    Forth function invocation\n          |            |            Third function invocation\n          | Second function invocation\nFirst function invocation\n```\n\n#","ref":"Buffy.ThrottleAndTimed.html#module-in-other-words-we-keep-the-throttle-mechanism"},{"type":"behaviour","title":"With the optionally enabled trigger, ending up in this lifecycle: - Buffy.ThrottleAndTimed","doc":"```mermaid\ngraph TB\n  A[Start Buffy] -->|start_link| B(Init Buffy)\n  B --> |initial handle_continue| W(Do throttled work)\n  S(Messages sent to Buffy) --> |message to trigger work| D{Can Throttle?}\n  D --> |YES| W\n  D --> |NO| C(Ignore message as throttle already scheduled)\n  S --> |empty inbox timeout interval| P(Do immediate work)\n  W --> |set message inbox timeout| S\n  P --> |set message inbox timeout| S\n```\n\n#","ref":"Buffy.ThrottleAndTimed.html#module-with-the-optionally-enabled-trigger-ending-up-in-this-lifecycle"},{"type":"behaviour","title":"Note on usage with Horde - Buffy.ThrottleAndTimed","doc":"Under Horde, the state unfortunately doesn't get synced up automatically - that requires explicit tooling.\nTherefore state will be \"reset\" to the initial state when process boots up. This is not a big issue as the initial state is to\nset a throttled run of `handle_throttle`.\n\n#","ref":"Buffy.ThrottleAndTimed.html#module-note-on-usage-with-horde"},{"type":"behaviour","title":"How to start timed interval triggers when your application boots up - Buffy.ThrottleAndTimed","doc":"By design this will not run when your application starts. If there's a need to start the inbox timeout,\nthen create a child spec for the application Supervisor (typically in `application.ex`)\nfor a Task module, that runs how many instances of `throttle/1` as necessary.\nExample implementation is:\n\n```\n# application.ex\ndef start(_type, _args) do\n  ...\n  children = [\n    ...\n    {true,\n     Supervisor.child_spec(\n       {Task,\n        fn ->\n          for x <- 1..10, do: MyModuleUsingThrottleAndTimed.throttle(some: \"value\", x: x)\n        end},\n       id: MyModuleUsingThrottleAndTimedInit,\n       restart: :temporary\n     )}\n  ]\n  ...\n```","ref":"Buffy.ThrottleAndTimed.html#module-how-to-start-timed-interval-triggers-when-your-application-boots-up"},{"type":"behaviour","title":"Example Usage - Buffy.ThrottleAndTimed","doc":"You'll first need to create a module that will be used to throttle.\n\n    defmodule MyTask do\n      use Buffy.ThrottleAndTimed,\n        throttle: :timer.minutes(2)\n        loop_timeout: :timer.minutes(2)\n\n      def handle_throttle(args) do\n        # Do something with args\n      end\n    end\n\nNext, you can use the `throttle/1` function with the registered module.\n\n    iex> MyTask.throttle(args)\n    :ok","ref":"Buffy.ThrottleAndTimed.html#module-example-usage"},{"type":"behaviour","title":"Options - Buffy.ThrottleAndTimed","doc":"- :throttle (`non_neg_integer`) - Required. The amount of time to wait before invoking the function. This value is in milliseconds.\n\n  - `:registry_module` (`atom`) - Optional. A module that implements the `Registry` behaviour. If you are running in a distributed instance, you can set this value to `Horde.Registry`. Defaults to `Registry`.\n\n  - `:registry_name` (`atom`) - Optional. The name of the registry to use. Defaults to the built in Buffy registry, but if you are running in a distributed instance you can set this value to a named `Horde.Registry` process. Defaults to `Buffy.Registry`.\n\n  - `:restart` (`:permanent` | `:temporary` | `:transient`) - Optional. The restart strategy to use for the GenServer. Defaults to `:temporary`.\n\n  - `:supervisor_module` (`atom`) - Optional. A module that implements the `DynamicSupervisor` behaviour. If you are running in a distributed instance, you can set this value to `Horde.DynamicSupervisor`. Defaults to `DynamicSupervisor`.\n\n  - `:supervisor_name` (`atom`) - Optional. The name of the dynamic supervisor to use. Defaults to the built in Buffy dynamic supervisor, but if you are running in a distributed instance you can set this value to a named `Horde.DynamicSupervisor` process. Defaults to `Buffy.DynamicSupervisor`.\n\n  - `:loop_interval` (`atom`) - Optional. The amount of time that this process will wait while inbox is empty until sending a `:timeout` message (handle via `handle_info`). Resets if message comes in. In milliseconds. Without this, the module would function exactly like `Buffy.Throttle`.","ref":"Buffy.ThrottleAndTimed.html#module-options"},{"type":"behaviour","title":"Example Usage: - Buffy.ThrottleAndTimed","doc":"#","ref":"Buffy.ThrottleAndTimed.html#module-example-usage"},{"type":"behaviour","title":"Have `throttle/1` add to data to state to process in `handle_throttle/1` - Buffy.ThrottleAndTimed","doc":"```\n  defmodule MyTimedSlowBucketingThrottler do\n    use Buffy.ThrottleAndTimed,\n      throttle: 100,\n      supervisor_module: DynamicSupervisor,\n      supervisor_name: MyDynamicSupervisor\n\n    def handle_throttle(%{test_pid: test_pid, values: values} = args) do\n      Process.sleep(200)\n      send(test_pid, {:ok, args, System.monotonic_time()})\n      values\n    end\n\n    def args_to_key(%{key: key}), do: key |> :erlang.term_to_binary() |> :erlang.phash2()\n\n    def update_args(%{values: values} = old_arg, %{values: new_values} = _new_arg)\n        when is_list(values) and is_list(new_values) do\n      %{old_arg | values: Enum.sort(values ++ new_values)}\n    end\n\n    def update_state_with_work_result(%{args: %{values: state_values} = args} = state, result) do\n      # because `handle_throttle()` runs in the `:continue` lifecycle of GenServer,\n      # inbox processing is paused until the logic completes. Inbox will continually get new messages,\n      # from calling `throttle()` and will be processed only after completion of `handle_throttle()`.\n      %{state | args: %{args | values: []}}\n    end\n  end\n```","ref":"Buffy.ThrottleAndTimed.html#module-have-throttle-1-add-to-data-to-state-to-process-in-handle_throttle-1"},{"type":"behaviour","title":"Using with Horde - Buffy.ThrottleAndTimed","doc":"If you are running Elixir in a cluster, you can utilize `Horde` to only run one of your throttled functions at a time. To do this, you'll need to set the `:registry_module` and `:supervisor_module` options to `Horde.Registry` and `Horde.DynamicSupervisor` respectively. You'll also need to set the `:registry_name` and `:supervisor_name` options to the name of the Horde registry and dynamic supervisor you want to use.\n\n      defmodule MyThrottler do\n        use Buffy.ThrottleAndTimed,\n          registry_module: Horde.Registry,\n          registry_name: MyApp.HordeRegistry,\n          supervisor_module: Horde.DynamicSupervisor,\n          supervisor_name: MyApp.HordeDynamicSupervisor,\n          throttle: :timer.minutes(2),\n          loop_timeout: :timer.minutes(10)\n\n        def handle_throttle(args) do\n          # Do something with args\n        end\n      end","ref":"Buffy.ThrottleAndTimed.html#module-using-with-horde"},{"type":"behaviour","title":"Telemetry - Buffy.ThrottleAndTimed","doc":"These are the events that are called by the `Buffy.ThrottleAndTimed` module:\n\n- `[:buffy, :throttle, :throttle]` - Emitted when the `throttle/1` function is called.\n- `[:buffy, :throttle, :timeout]` - Emitted when inbox timeout is triggered.\n- `[:buffy, :throttle, :handle, :start]` - Emitted at the start of the `handle_throttle/1` function.\n- `[:buffy, :throttle, :handle, :stop]` - Emitted at the end of the `handle_throttle/1` function.\n- `[:buffy, :throttle, :handle, :exception]` - Emitted when an error is raised in the `handle_throttle/1` function.\n\nAll of these events will have the following metadata:\n\n- `:args` - The arguments passed to the `throttle/1` function.\n- `:key` - A hash of the passed arguments used to deduplicate the throttled function.\n- `:module` - The module using `Buffy.ThrottleAndTimed`.\n\nWith the additional metadata for `[:buffy, :throttle, :handle, :stop]`:\n\n- `:result` - The return value of the `handle_throttle/1` function.","ref":"Buffy.ThrottleAndTimed.html#module-telemetry"},{"type":"callback","title":"Buffy.ThrottleAndTimed.handle_throttle/1","doc":"The function called after the throttle has completed. This function will\nreceive the arguments passed to the `throttle/1` function.","ref":"Buffy.ThrottleAndTimed.html#c:handle_throttle/1"},{"type":"callback","title":"Buffy.ThrottleAndTimed.throttle/1","doc":"A function to call the throttle. This will start\nand wait the configured `throttle` time before calling the `c:handle_throttle/1`\nfunction.","ref":"Buffy.ThrottleAndTimed.html#c:throttle/1"},{"type":"type","title":"Buffy.ThrottleAndTimed.args/0","doc":"A list of arbitrary arguments that are used for the `c:handle_throttle/1`\nfunction.","ref":"Buffy.ThrottleAndTimed.html#t:args/0"},{"type":"type","title":"Buffy.ThrottleAndTimed.key/0","doc":"A unique key for debouncing. This is used for GenServer uniqueness and is\ngenerated from hashing all of the args.","ref":"Buffy.ThrottleAndTimed.html#t:key/0"},{"type":"type","title":"Buffy.ThrottleAndTimed.state/0","doc":"Internal state that `Buffy.ThrottleAndTimed` keeps.","ref":"Buffy.ThrottleAndTimed.html#t:state/0"},{"type":"extras","title":"Buffy","doc":"# Buffy\n\nBuffy is a small library of Elixir modules to assist in throttling and debouncing function calling.","ref":"readme.html"},{"type":"extras","title":"Roadmap - Buffy","doc":"- [ ] Allow limiting concurrency of running tasks\n- [ ] Create a debounce module\n- [X] Telemetry instrumentation","ref":"readme.html#roadmap"},{"type":"extras","title":"Installation - Buffy","doc":"Just add [`buffy`](https://hex.pm/packages/buffy) to your `mix.exs` file like so:\n\n \n```elixir\ndef deps do\n  [\n    {:buffy, \"~> 2.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Published Documentation - Buffy","doc":"Documentation is automatically generated and published to [HexDocs](https://hexdocs.pm/buffy/readme.html) on new releases.","ref":"readme.html#published-documentation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [2.2.0](https://github.com/stordco/buffy/compare/v2.1.1...v2.2.0) (2024-03-13)\n\n\n#","ref":"changelog.html"},{"type":"extras","title":"Features - Changelog","doc":"* SIGNAL-5811 add time interval bucket feature to ThrottleAndTimed and make loop_interval optional ([#39](https://github.com/stordco/buffy/issues/39)) ([3d48d04](https://github.com/stordco/buffy/commit/3d48d04a3b25ffb8209a79c65926c1f4a8f4debe))\n\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Sync files with stordco/common-config-elixir ([#27](https://github.com/stordco/buffy/issues/27)) ([d7cffde](https://github.com/stordco/buffy/commit/d7cffdeb910491418afdd21ff8fa12e96bb00c94))\n* Sync files with stordco/common-config-elixir ([#38](https://github.com/stordco/buffy/issues/38)) ([c127668](https://github.com/stordco/buffy/commit/c1276688bfe69481abd7b6559453a6653cbc99a6))\n\n## [2.1.1](https://github.com/stordco/buffy/compare/v2.1.0...v2.1.1) (2023-12-18)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* SIGNAL-5504 fix usage of option fields and typespec ([#32](https://github.com/stordco/buffy/issues/32)) ([fbb8fd2](https://github.com/stordco/buffy/commit/fbb8fd25b778846afd6e919100ca56b96b220aee))\n\n## [2.1.0](https://github.com/stordco/buffy/compare/v2.0.1...v2.1.0) (2023-12-15)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Features - Changelog","doc":"* Add jitter option to throttle function ([#26](https://github.com/stordco/buffy/issues/26)) ([7991f91](https://github.com/stordco/buffy/commit/7991f91dc09e34d1478a999d771b1be3fd5a88b9))\n\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Debounce should be throttle ([#30](https://github.com/stordco/buffy/issues/30)) ([c0cd187](https://github.com/stordco/buffy/commit/c0cd187af50e3fc60c47464d2cf9ecc62e26f086))\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Sync files with stordco/common-config-elixir ([#23](https://github.com/stordco/buffy/issues/23)) ([68bdd18](https://github.com/stordco/buffy/commit/68bdd18cacd7fef8007aa59def429c5b43f3c16a))\n\n## [2.0.1](https://github.com/stordco/buffy/compare/v2.0.0...v2.0.1) (2023-10-03)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Update callback to match spec ([#21](https://github.com/stordco/buffy/issues/21)) ([5902653](https://github.com/stordco/buffy/commit/59026530d3daf561e209d441b3b98dd1634b2aaa))\n\n## [2.0.0](https://github.com/stordco/buffy/compare/v1.2.2...v2.0.0) (2023-10-02)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"⚠ BREAKING CHANGES - Changelog","doc":"* `Buffy.Throttle.throttle/1` will now return `:ok` instead of `{:ok, pid}`\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Return :ok for already started throttle processes ([#20](https://github.com/stordco/buffy/issues/20)) ([07909be](https://github.com/stordco/buffy/commit/07909be0e65c3afb088b6d356862c597912ea157))\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Remove old publish workflow ([#15](https://github.com/stordco/buffy/issues/15)) ([4b10fec](https://github.com/stordco/buffy/commit/4b10fec5cf76a4ff3e28a153bf91d126d203cfee))\n* Sync files with stordco/common-config-elixir ([#18](https://github.com/stordco/buffy/issues/18)) ([bfe20fd](https://github.com/stordco/buffy/commit/bfe20fd470e7c70963e3770bf14f744f35843300))\n* Sync files with stordco/common-config-elixir ([#19](https://github.com/stordco/buffy/issues/19)) ([7395018](https://github.com/stordco/buffy/commit/73950186902771e381165b253ab41c94730b8362))\n* Update Hex Link in README.md ([#17](https://github.com/stordco/buffy/issues/17)) ([68927c6](https://github.com/stordco/buffy/commit/68927c6b8f42fa4e6a21c0323592c10bfeb7f8e2))\n\n## [1.2.2](https://github.com/stordco/buffy/compare/v1.2.1...v1.2.2) (2023-09-26)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Do not double supervise throttle module ([#13](https://github.com/stordco/buffy/issues/13)) ([ce046ba](https://github.com/stordco/buffy/commit/ce046bab47f6a622aad586af59f9caf061c99e28))\n* Ensure to always hash binary version of args ([#14](https://github.com/stordco/buffy/issues/14)) ([6216805](https://github.com/stordco/buffy/commit/6216805da569a90e42b2b40693934e3a3d7abbc9))\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Sync files with stordco/common-config-elixir ([#10](https://github.com/stordco/buffy/issues/10)) ([930fabe](https://github.com/stordco/buffy/commit/930fabef4d0815cfe144893091537d3405a12629))\n* Sync files with stordco/common-config-elixir ([#12](https://github.com/stordco/buffy/issues/12)) ([7d190da](https://github.com/stordco/buffy/commit/7d190da93eaaf2be765f0b6a31ff9c419f51a06e))\n\n## [1.2.1](https://github.com/stordco/buffy/compare/v1.2.0...v1.2.1) (2023-08-24)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Make buffy public ([#8](https://github.com/stordco/buffy/issues/8)) ([d1eb14f](https://github.com/stordco/buffy/commit/d1eb14fde266b97cf2e84d65914d568e73d827b8))\n\n## [1.2.0](https://github.com/stordco/buffy/compare/v1.1.0...v1.2.0) (2023-08-24)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Features - Changelog","doc":"* Add telemetry to the throttle module ([#7](https://github.com/stordco/buffy/issues/7)) ([74539d8](https://github.com/stordco/buffy/commit/74539d86ea41c531d4743ad57f614fd0f359679e))\n\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Add MIT license ([#5](https://github.com/stordco/buffy/issues/5)) ([fc4306a](https://github.com/stordco/buffy/commit/fc4306afb90b301860f549afe8950bf96aff9f62))\n* Sync files with stordco/common-config-elixir ([#3](https://github.com/stordco/buffy/issues/3)) ([d8bdce2](https://github.com/stordco/buffy/commit/d8bdce2a9114885c8993e45d5b80df8008dc84a4))\n* Update README ([#6](https://github.com/stordco/buffy/issues/6)) ([a874e46](https://github.com/stordco/buffy/commit/a874e46bcb35fe6ed7244e6d831ec8d620fa35ad))\n\n## [1.1.0](https://github.com/stordco/buffy/compare/v1.0.0...v1.1.0) (2023-07-13)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Features - Changelog","doc":"* Make types and logic flow more clear ([7c57e46](https://github.com/stordco/buffy/commit/7c57e46d12941bbc4b79a7b01f7e40f948cd8d13))\n* Setup basic elixir repository ([785b3b8](https://github.com/stordco/buffy/commit/785b3b8b158668ecc40a3437d992abe500a1883d))\n* Simplify first module usage ([b13c522](https://github.com/stordco/buffy/commit/b13c52230116abad7bb258317e4bf260f8706a6f))\n\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Update release please version ([33aa3c3](https://github.com/stordco/buffy/commit/33aa3c34139fe0669ee53c12b1f5467df4359270))\n* Update test stream data to only run 500 times ([5a423ad](https://github.com/stordco/buffy/commit/5a423ad3324c83809a4c1758bcbd300c4d56fd04))\n* Update test timeout to account for large CI runs ([535c739](https://github.com/stordco/buffy/commit/535c7392df9b74c95ef448177f9106aeb85fdc25))\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Remove credo debug file ([1f1419b](https://github.com/stordco/buffy/commit/1f1419b5eccbfdef46f10c6c421f34c9505e72e4))\n* Rename debounce module to throttle ([73d0cf5](https://github.com/stordco/buffy/commit/73d0cf58ea24f6769af6db46d6f62929cc7ab1ae))\n* Sync files with stordco/common-config-elixir ([#2](https://github.com/stordco/buffy/issues/2)) ([c6e4f34](https://github.com/stordco/buffy/commit/c6e4f3465475bd7bbe7571a76a963dd5c74dba3a))\n* Update Buffy.Throttle moduledoc ([c906c43](https://github.com/stordco/buffy/commit/c906c43c1d783cb8175d11f47d21e961a647812a))","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"LICENSE","doc":"The MIT License (MIT)\n\nCopyright (c) 2023-present STORD, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}